# streamlit-advanced-plotly-chart
This is a streamlit custom component to preserve the zoom level of a plotly chart when getting event data from it.
It is based on the [streamlit-plotly-events](https://github.com/null-jones/streamlit-plotly-events/tree/master) component.
